summaryrefslogtreecommitdiffstats
path: root/c++/src/H5AbstractDs.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'c++/src/H5AbstractDs.cpp')
-rw-r--r--c++/src/H5AbstractDs.cpp42
1 files changed, 35 insertions, 7 deletions
diff --git a/c++/src/H5AbstractDs.cpp b/c++/src/H5AbstractDs.cpp
index 33fadc5..9e54d94 100644
--- a/c++/src/H5AbstractDs.cpp
+++ b/c++/src/H5AbstractDs.cpp
@@ -96,17 +96,17 @@ DataType AbstractDs::getDataType() const
}
//--------------------------------------------------------------------------
// Function: AbstractDs::getEnumType
///\brief Returns the enumeration datatype of this abstract dataset which
/// can be a dataset or an attribute.
-///\return EnumType instance
+///\return ArrayType instance
///\exception H5::DataTypeIException
-// Programmer Binh-Minh Ribler - 2000
+// Programmer Binh-Minh Ribler - Jul, 2005
//--------------------------------------------------------------------------
-EnumType AbstractDs::getEnumType() const
+ArrayType AbstractDs::getArrayType() const
{
- EnumType enumtype(p_get_type());
- return(enumtype);
+ ArrayType arraytype(p_get_type());
+ return(arraytype);
}
//--------------------------------------------------------------------------
@@ -124,6 +124,20 @@ CompType AbstractDs::getCompType() const
}
//--------------------------------------------------------------------------
+// Function: AbstractDs::getEnumType
+///\brief Returns the enumeration datatype of this abstract dataset which
+/// can be a dataset or an attribute.
+///\return EnumType instance
+///\exception H5::DataTypeIException
+// Programmer Binh-Minh Ribler - 2000
+//--------------------------------------------------------------------------
+EnumType AbstractDs::getEnumType() const
+{
+ EnumType enumtype(p_get_type());
+ return(enumtype);
+}
+
+//--------------------------------------------------------------------------
// Function: AbstractDs::getIntType
///\brief Returns the integer datatype of this abstract dataset which
/// can be a dataset or an attribute.
@@ -166,6 +180,20 @@ StrType AbstractDs::getStrType() const
}
//--------------------------------------------------------------------------
+// Function: AbstractDs::getVarLenType
+///\brief Returns the floating-point datatype of this abstract dataset,
+/// which can be a dataset or an attribute.
+///\return VarLenType instance
+///\exception H5::DataTypeIException
+// Programmer Binh-Minh Ribler - Jul, 2005
+//--------------------------------------------------------------------------
+VarLenType AbstractDs::getVarLenType() const
+{
+ VarLenType varlentype(p_get_type());
+ return(varlentype);
+}
+
+//--------------------------------------------------------------------------
// Function: AbstractDs destructor
///\brief Noop destructor.
// Programmer Binh-Minh Ribler - 2000
@@ -96,17 +96,17 @@ DataType AbstractDs::getDataType() const
}
//--------------------------------------------------------------------------
-// Function: AbstractDs::getEnumType
-///\brief Returns the enumeration datatype of this abstract dataset which
+// Function: AbstractDs::getArrayType
+///\brief Returns the compound datatype of this abstract dataset which
/// can be a dataset or an attribute.